@@ -101,15 +101,28 @@ class Rule(ABC):
 
 class ResourceSpecificRule(Rule):
     """
-    Base class for rules that only apply to a subset of resource types
+    Base class for rules that only apply to a subset of resource types.
+
+    RESOURCE_TYPES: Resources to invoke the rule for.
+    EXCLUDED_RESOURCE_TYPES: Resources to explicitly not run the rule for.
+
+    Both fields are included to allow for more granular rule definitions. For example,
+    you may want to allow all resources except S3BucketPolicies, in which case you
+    would define these variables as:
+
+    EXCLUDED_RESOURCE_TYPES = (S3BucketPolicy,)
+    RESOURCE_TYPES = (Resource,)
+
+    Where the `S3BucketPolicy` Resource inherits from the base `Resource` class.
     """
 
+    EXCLUDED_RESOURCE_TYPES: Tuple[Type] = tuple()
     RESOURCE_TYPES: Tuple[Type] = tuple()
 
     def invoke(self, cfmodel: CFModel, extras: Optional[Dict] = None) -> Result:
         result = Result()
         for logical_id, resource in cfmodel.Resources.items():
-            if isinstance(resource, self.RESOURCE_TYPES):
+            if isinstance(resource, self.RESOURCE_TYPES) and not isinstance(resource, self.EXCLUDED_RESOURCE_TYPES):
                 result += self.resource_invoke(resource=resource, logical_id=logical_id, extras=extras)
         return result
 
@@ -119,7 +132,20 @@ class ResourceSpecificRule(Rule):
 
 
 class PrincipalCheckingRule(Rule, ABC):
-    """Abstract class for rules that check principals"""
+    """
+    Abstract class for rules that check principals.
+
+    `valid_principals` is a set of the following Account IDs and Canonical IDs:
+      - `aws_principals` set in the user defined config (default = None)
+      - ELB Log Account IDs from AWS
+      - ElastiCache Backup Canonical IDs
+      - (if defined) The AWS Account in the config which CFRipper is executing with
+
+    When using `valid_principals`, make sure the scope of accounts allowed is not too large.
+    It might be the case that the account the stack is being deployed in is in this set.
+    This could raise false negatives in rules. If a rule should only be exempt for AWS Service
+    IDs, such as ELB and ElastiCache, consider using `_get_whitelist_from_config()` directly.
+    """
 
     _valid_principals = None
 
